package Bundle::Locale::CLDR::Northernafrica;

use version;

our $VERSION = version->declare('v0.44.1');

=head1 NAME

Bundle::Locale::CLDR::Northernafrica

=head1 CONTENTS

Locale::CLDR::Locales::Ar 0.44.1

Locale::CLDR::Locales::Es 0.44.1

Locale::CLDR::Locales::Fr 0.44.1

Locale::CLDR::Locales::Kab 0.44.1

Locale::CLDR::Locales::Rif 0.44.1

Locale::CLDR::Locales::Shi 0.44.1

Locale::CLDR::Locales::Tzm 0.44.1

Locale::CLDR::Locales::Zgh 0.44.1

Locale::CLDR::Locales::Ar::Arab 0.44.1

Locale::CLDR::Locales::Es::Latn 0.44.1

Locale::CLDR::Locales::Fr::Latn 0.44.1

Locale::CLDR::Locales::Ha::Arab 0.44.1

Locale::CLDR::Locales::Kab::Latn 0.44.1

Locale::CLDR::Locales::Rif::Latn 0.44.1

Locale::CLDR::Locales::Shi::Latn 0.44.1

Locale::CLDR::Locales::Shi::Tfng 0.44.1

Locale::CLDR::Locales::Tzm::Latn 0.44.1

Locale::CLDR::Locales::Zgh::Tfng 0.44.1

Locale::CLDR::Locales::Ar::Arab::Dz 0.44.1

Locale::CLDR::Locales::Ar::Arab::Eg 0.44.1

Locale::CLDR::Locales::Ar::Arab::Eh 0.44.1

Locale::CLDR::Locales::Ar::Arab::Ly 0.44.1

Locale::CLDR::Locales::Ar::Arab::Ma 0.44.1

Locale::CLDR::Locales::Ar::Arab::Sd 0.44.1

Locale::CLDR::Locales::Ar::Arab::Tn 0.44.1

Locale::CLDR::Locales::En::Latn::Sd 0.44.1

Locale::CLDR::Locales::Es::Latn::Ea 0.44.1

Locale::CLDR::Locales::Es::Latn::Ic 0.44.1

Locale::CLDR::Locales::Fr::Latn::Dz 0.44.1

Locale::CLDR::Locales::Fr::Latn::Ma 0.44.1

Locale::CLDR::Locales::Fr::Latn::Tn 0.44.1

Locale::CLDR::Locales::Ha::Arab::Sd 0.44.1

Locale::CLDR::Locales::En::Latn::001 0.44.1

Locale::CLDR::Locales::Kab::Latn::Dz 0.44.1

Locale::CLDR::Locales::Rif::Latn::Ma 0.44.1

Locale::CLDR::Locales::Shi::Latn::Ma 0.44.1

Locale::CLDR::Locales::Shi::Tfng::Ma 0.44.1

Locale::CLDR::Locales::Tzm::Latn::Ma 0.44.1

Locale::CLDR::Locales::Zgh::Tfng::Ma 0.44.1


=cut

1;

